--[[ =================================================================
    Description:
        All globals used within UberInventory.
    ================================================================= --]]

-- Colors used within UberInventory
    C_GOLD   = "|cFFFFD700";
    C_SILVER = "|cFFC7C7CF";
    C_COPPER = "|cFFEDA55F";
    C_GREEN  = "|cFF00FF00";
    C_WHITE  = "|cFFFFFFFF";
    C_BLUE   = "|cFF3366FF";
    C_RED    = "|cFFFF0000";
    C_YELLOW = "|cFFFFFF00";
    C_GREY   = "|cFFAAAAAA";
    C_CLOSE  = "|r";

-- Global variables
    UBI = getglobal( "UBI" ); -- AddOn object itself
    UBI_NAME = GetAddOnMetadata( "UberInventory", "Title" );
    UBI_VERSION = GetAddOnMetadata( "UberInventory", "Version" );
    UBI_NAME_VERSION = UBI_NAME.." - "..UBI_VERSION;
    UBI_WEBSITE = C_BLUE.."http://redeye.xs4all.nl/ubi/"..C_WHITE;
    UBI_REALM = GetRealmName();
    UBI_PLAYER = UnitName( "player" );
    UBI_GUILD = GetGuildInfo( "player" );
    UBI_FACTION = UnitFactionGroup( "player" );
    UBI_BANK_OPEN = false;
    UBI_MAILBOX_OPEN = false;
    UBI_GUILDBANK_OPEN = false;
    UBI_Item = {}; -- Used when adding dropdown items
    UBI_SEC_IN_DAY = 60 * 60 * 24;
    UBI_Events = {}; -- Used to tracking event counts
    UBI_DEBUG = false; -- Used for debugging purposes, should be set to false normally
    UBI_VERSION_WARNING = false; -- Received version warning
    UBI_TooltipItem = nil; -- Filled from main inventory frame (used to show correct counts when showing alt information)
    UBI_TooltipLocation = nil; -- Filled from main inventory frame (used to hide alt if the alt is viewed)

-- Alts and Guildbanks
    UBI_Characters = {};  -- Used for list of alt characters
    UBI_Guildbanks = {}; -- Used for list of guildbanks

-- Globals for receiving guildbank data
    UBI_GBData = {}; -- Array for receiving guildbank data through the guild chat channel
    UBI_GBSender = nil; -- Who is sending guildbank data (only the latest player is tracked)

-- Days between collection events before message is displayed to visit mailbox, bank or guildbank
    UBI_MAILBOX_VISIT_INTERVAL = 21; -- in days
    UBI_BANK_VISIT_INTERVAL = 30; -- in days
    UBI_GUILDBANK_VISIT_INTERVAL = 14; -- in days

-- Filter settings
    UBI_FILTER_TEXT = "";              -- Default no search string
    UBI_FILTER_LOCATIONS = 1;          -- Default all items
    UBI_FILTER_QUALITY = 1;            -- Default all qualities
    UBI_FILTER_CLASSES = 1;            -- Default all classes
    UBI_SHOWING_GUILDBANK = false;     -- Not showing the guildbank

-- Scrolling variables
    UBI_PAGE = 0;                      -- Starting page
    UBI_PIX_PER_PAGE = 0;              -- Pixels per page (related to height of scrollbar, calculated as (height-32)/2, done in the XML document)
    UBI_SCROLLBAR = nil;               -- ScrollFrame object

-- Equip slots
    UBI_EQUIP_SLOTS = { "HeadSlot",
                        "NeckSlot",
                        "ShoulderSlot",
                        "BackSlot",
                        "ChestSlot",
                        "ShirtSlot",
                        "TabardSlot",
                        "WristSlot",
                        "HandsSlot",
                        "WaistSlot",
                        "LegsSlot",
                        "FeetSlot",
                        "Finger0Slot",
                        "Finger1Slot",
                        "Trinket0Slot",
                        "Trinket1Slot",
                        "MainHandSlot",
                        "SecondaryHandSlot",
                        "RangedSlot" }; -- AmmoSlot is excluded, counts as 1 regardless number of arrows. bullets are linked

-- Quality names (using Blizzards localized strings) and colors
    UBI_QUALITY = { ITEM_QUALITY0_DESC,
                    ITEM_QUALITY1_DESC,
                    ITEM_QUALITY2_DESC,
                    ITEM_QUALITY3_DESC,
                    ITEM_QUALITY4_DESC,
                    ITEM_QUALITY5_DESC,
                    ITEM_QUALITY6_DESC };

-- Location texture (Guildbank image dynamic based on faction)
    UBI_LOCATION_TEXTURE = { [1] = nil,
                             [2] = "Interface\\AddOns\\UberInventory\\bag",
                             [3] = "Interface\\AddOns\\UberInventory\\bank",
                             [4] = "Interface\\AddOns\\UberInventory\\key",
                             [5] = "Interface\\AddOns\\UberInventory\\mail",
                             [6] = "Interface\\AddOns\\UberInventory\\equipped",
                             [7] = "Interface\\AddOns\\UberInventory\\"..string.lower( UBI_FACTION ) };

-- Frame related options
    UBI_NUM_ITEMBUTTONS = 16;

-- Saved variable
    UBI_Data = {}; -- Main data structure for UberInventory (items, prices, options)

-- Inventory items (Sorted and filtered)
    UBI_Sorted = {};
    UBI_Inventory_count = 0;
    UBI_Items_Work = {};

-- Tooltip hook related stuff
    UberInventory_ItemTooltip_Original = nil;
    currentItemCount = 0;
    currentItemId = nil;
    UBI_Hooks = {};
    UBI_Hooks["OnTooltipSetItem"] = {};
    UBI_Hooks["OnTooltipCleared"] = {};

-- Special Money type for the cash mail moneyframe
    MoneyTypeInfo["CASH_MAIL"] = {
        UpdateFunc = function()
            return 0;
        end,
        collapse = 1,
        truncateSmallCoins = nil,
        showSmallerCoins = "Backpack"
    };

-- Performance related options
   UBI_DISP_COUNT = 0;